#!/bin/bash

# If OS run in memory setup alpine and reboot
ROOTFS=`awk '$2=="/" {print $1}' /etc/mtab`
if [ "$ROOTFS" = "tmpfs" ]; then 

DEVICE=`lsblk -n -o NAME,TYPE | awk '/disk/ {print $1}'`
# for unnatended mode
ERASE_DISKS="/dev/${DEVICE}"
export ERASE_DISKS
TIMEZONE=`curl -s http://ip-api.com/line/?fields=timezone`
ANSWERS_FILE="UNATTENDED-setup-alpine-for-asteraid-on-${DEVICE}.cfg"

tee ${ANSWERS_FILE} << EOF
KEYMAPOPTS="us us"
HOSTNAMEOPTS=asteraid
DEVDOPTS=mdev
INTERFACESOPTS="auto lo
iface lo inet loopback
auto eth0
iface eth0 inet dhcp
"
TIMEZONEOPTS="$TIMEZONE"
PROXYOPTS=none
APKREPOSOPTS="-1"
USEROPTS="-a -u -g audio,video,netdev ansible"
USERSSHKEY="https://pxe.dmmp.me/alpine/ssh_key"
SSHDOPTS=openssh
ROOTSSHKEY="https://pxe.dmmp.me/alpine/ssh_key"
NTPOPTS="openntpd"
DISKOPTS="-L -m sys $ERASE_DISKS"
LBUOPTS=none
APKCACHEOPTS=none
EOF

Red='\033[0;31m'
Green='\033[0;32m'
Yellow='\033[0;33m'
NC='\033[0m' # No Color

echo
echo -e "${Green}-------------------------------------------------------${NC}"
echo -e "Setup created unattended installation answer file"
echo -e "${Yellow}${ANSWERS_FILE}${NC}"
echo -e "It will install Alpine Linux on this computer by doing the following:"
echo -e "1. For the interface eth0 will be assigned a dhcp address"
echo -e "2. The first hard disk (${Yellow}${DEVICE}${NC}) will be formatted"
echo -e "If you prefer to do partitioning ${Red}WITHOUT WARNIG${NC} run command"
echo -e "# ${Yellow}export ERASE_DISKS=/dev/${DEVICE}${NC}"
echo -e "3. timezone will be set to ${Yellow}$TIMEZONE${NC}"
echo -e "If necessary, rewview the installation script, then run the command"
echo -e "# ${Yellow}setup-alpine -ef ${ANSWERS_FILE} ${NC}"
echo -e "Then ${Yellow}reboot${NC}, login as root without password and run setup-asteraid.sh again"

exit 0 

#setup-alpine -ef ${ANSWERS_FILE}
#reboot

fi

VENDORDIR=/opt/plentystars
PROJECTDIR=${VENDORDIR}/asteraid

# If asteraid already installed exit 0
[ -d ${VENDORDIR}/asteraid ] && exit 0

echo "http://dl-cdn.alpinelinux.org/alpine/edge/testing" >> /etc/apk/repositories
apk add --update asterisk asterisk-odbc git mariadb mariadb-client mariadb-connector-odbc py-pip libpanelw ansible rrdtool rrdtool-cached

sed -e 's/^skip-networking/#skip-networking/' -i /etc/my.cnf.d/mariadb-server.cnf
/etc/init.d/mariadb setup
rc-update add mariadb default
rc-service mariadb start
rc-update add asterisk default

mkdir -p ${VENDORDIR}
cd ${VENDORDIR}
# Node install
NODEVER=node-v16.20.1-linux-x64
#wget https://nodejs.org/dist/latest-v16.x/node-v16.20.0-linux-x64.tar.gz
wget https://repo.dmmp.me/${NODEVER}.tar.gz
tar -xzf ${NODEVER}.tar.gz
ln -s ${NODEVER} node
cp -r ${NODEVER}/* /usr/local/
git clone https://gitlab.com/plentystars/asteraid-code.git asteraid
cd asteraid
npm install

DBCONF="a_conf"
DBCDR="a_cdr"
SECRET=$(cat /dev/urandom | tr -dc 'a-zA-Z0-9~_-' | head -c 12)
CONFIG_USER=${PROJECTDIR}/config_user

tee ${CONFIG_USER} << EOF
db_user=asteraid
db_password=${SECRET}
db_host=localhost
db_database=${DBCONF}
cdr_database=${DBCDR}
EOF

chmod 0600 ${PROJECTDIR}/config_user

mysql -e "CREATE DATABASE IF NOT EXISTS ${DBCONF};"
mysql ${DBCONF} < ${PROJECTDIR}/dump/conf.sql
mysql -e "CREATE DATABASE IF NOT EXISTS ${DBCDR};"
mysql ${DBCDR} < ${PROJECTDIR}/dump/a_cdr.sql
mysql -e "DROP USER IF EXISTS 'asteraid'@'localhost';"
mysql -e "CREATE USER 'asteraid'@'localhost' IDENTIFIED BY '${SECRET}';"
mysql -e "GRANT ALL PRIVILEGES ON ${DBCONF}.* TO 'asteraid'@'localhost' WITH GRANT OPTION;"
mysql -e "GRANT ALL PRIVILEGES ON ${DBCDR}.* TO 'asteraid'@'localhost' WITH GRANT OPTION;"
mysql -e "GRANT SELECT ON mysql.proc TO 'asteraid'@'localhost';"
mysql -e "FLUSH PRIVILEGES;"

#if [ ! -f ~/.my.cnf ]; then
#  echo "[mysql]" > ~/.my.cnf
#  echo user=asteraid >> ~/.my.cnf
#  echo password=${SECRET} >> ~/.my.cnf
#fi

tee /etc/odbcinst.ini << EOF
[MariaDB]
Driver = /usr/lib/mariadb/libmaodbc.so
EOF

tee /etc/odbc.ini << EOF
[asteriskcdrdb]
Description = Asterisk CDR
Driver      = MariaDB
SERVER      = localhost
USER        = asteraid
PASSWORD    = ${SECRET}
PORT        = 3306
DATABASE    = a_cdr
Option      = 3
EOF

chown root:asterisk /etc/odbc.ini
chmod 0660 /etc/odbc.ini

apk add py-pip libpanelw ansible
pip install mysql-connector-python
mkdir -p /usr/share/ansible/plugins/modules
cp ${PROJECTDIR}/usr/share/ansible/plugins/modules/sql2conf.py3 /usr/share/ansible/plugins/modules/sql2conf.py
cp ${PROJECTDIR}/etc/conf.d/rrdcached /etc/conf.d/rrdcached
cp ${PROJECTDIR}/bin/apply.sh /usr/bin/apply.sh

[ -r ${PROJECTDIR}/config ] && source ${PROJECTDIR}/config
[ -r ${PROJECTDIR}/config_user ] && source ${PROJECTDIR}/config_user

function rrd_create(){
  if [ ! -f $RRD ]; then

    [ ! -d $RRDIR ] && mkdir -p $RRDIR

    NOW=$(date +%s)
    rrdtool create $RRD --start $NOW --step 5 \
        DS:system_uptime:COUNTER:10:0:U \
        DS:cpu_usage:GAUGE:10:0:U \
        DS:disk_usage:GAUGE:10:0:U \
        DS:mem_usage:GAUGE:10:0:U \
        DS:current_calls:GAUGE:10:0:U \
        DS:processed_calls:COUNTER:10:0:U \
        DS:asterisk_uptime:COUNTER:10:0:U \
        DS:module_uptime:COUNTER:10:0:U \
        DS:sip_online:COUNTER:10:0:U \
        DS:sip_offline:COUNTER:10:0:U \
        RRA:AVERAGE:0.1:3:5760 \
        RRA:AVERAGE:0.1:120:144 \
        RRA:AVERAGE:0.1:180:2976 \
        RRA:AVERAGE:0.1:720:8784

  fi
}

RRDIR=${storeDir%/}/${rrdDir%/}
RRD="${RRDIR}/sysinfo.rrd"
rrd_create

for openrc_script in asteraid rrdcached rrdagent; do 
  cp ${PROJECTDIR}/etc/init.d/$openrc_script /etc/init.d/$openrc_script
  rc-update add $openrc_script default
  rc-service $openrc_script start
done

addgroup ansible asterisk
